@@ -28,6 +28,7 @@ from dynatrace.configuration_v1.plugins import PluginService
 from dynatrace.environment_v1.cluster_time import ClusterTimeService
 from dynatrace.environment_v1.custom_device import CustomDeviceService
 from dynatrace.environment_v1.event import EventService
+from dynatrace.environment_v1.smartscape_hosts import SmartScapeHostsService
 from dynatrace.environment_v1.synthetic_monitors import SyntheticMonitorsService
 from dynatrace.environment_v1.synthetic_third_party import ThirdPartySyntheticTestsService
 from dynatrace.environment_v1.timeseries import TimeSerieService
@@ -57,16 +58,7 @@ class Dynatrace:
         mc_sso_csrf_cookie: Optional[str] = None,
     ):
         self.__http_client = HttpClient(
-            base_url,
-            token,
-            log,
-            proxies,
-            too_many_requests_strategy,
-            retries,
-            retry_delay_ms,
-            mc_jsession_id,
-            mc_b925d32c,
-            mc_sso_csrf_cookie,
+            base_url, token, log, proxies, too_many_requests_strategy, retries, retry_delay_ms, mc_jsession_id, mc_b925d32c, mc_sso_csrf_cookie,
         )
 
         self.activegates: ActiveGateService = ActiveGateService(self.__http_client)
@@ -86,6 +78,7 @@ class Dynatrace:
         self.metrics: MetricService = MetricService(self.__http_client)
         self.notifications: NotificationService = NotificationService(self.__http_client)
         self.plugins: PluginService = PluginService(self.__http_client)
+        self.smartscape_hosts: SmartScapeHostsService = SmartScapeHostsService(self.__http_client)
         self.synthetic_monitors: SyntheticMonitorsService = SyntheticMonitorsService(self.__http_client)
         self.tenant_tokens = TenantTokenService(self.__http_client)
         self.third_part_synthetic_tests: ThirdPartySyntheticTestsService = ThirdPartySyntheticTestsService(self.__http_client)
